Module: SimpleNavigation::ControllerMethods::ClassMethods
- Defined in:
- lib/simple_navigation/rails_controller_methods.rb
Instance Method Summary collapse
-
#navigation(*args) ⇒ Object
Sets the active navigation for all actions in this controller.
Instance Method Details
#navigation(*args) ⇒ Object
Sets the active navigation for all actions in this controller.
The specified symbol must match the keys for your navigation items in your config/navigation.rb file.
127 128 129 130 131 132 133 134 135 |
# File 'lib/simple_navigation/rails_controller_methods.rb', line 127 def (*args) class_eval do define_method :sn_set_navigation do (*args) end protected :sn_set_navigation before_filter :sn_set_navigation end end |